pub struct LowPrioritySceneBuilderThread {
pub rx: Receiver<SceneBuilderRequest>,
pub tx: Sender<SceneBuilderRequest>,
pub tile_pool: BlobTilePool,
}Expand description
A scene builder thread which executes expensive operations such as blob rasterization with a lower priority than the normal scene builder thread.
After rasterizing blobs, the secene building request is forwarded to the normal scene builder where the FrameBuilder is generated.
Fields
rx: Receiver<SceneBuilderRequest>tx: Sender<SceneBuilderRequest>tile_pool: BlobTilePoolImplementations
Sourceimpl LowPrioritySceneBuilderThread
impl LowPrioritySceneBuilderThread
pub fn run(&mut self)
fn process_transaction( &mut self, txn: Box<TransactionMsg>, ) -> Box<TransactionMsg>